import os
import unittest
from trello import TrelloClient
from trello.util import create_oauth_token

class TrestoTestCase(unittest.TestCase):
    board_name = 'Tresto'
    test_passed_list = 'PASSED'
    test_failed_list = 'FAILED'
    auto_create_board = False
    auto_create_lists = False

    @classmethod
    def setUpClass(cls):
        api_key = os.environ['TRELLO_API_KEY']
        api_token = os.environ['TRELLO_API_TOKEN']

        cls.trello_client = TrelloClient(api_key=api_key, api_secret=None, token=api_token)

        # Find or create the board
        if cls.auto_create_board:
            cls.board = cls._find_or_create_board(cls.board_name)
        else:
            cls.board = cls._find_board(cls.board_name)

        # Find or create lists
        if cls.auto_create_lists:
            cls.passed_list = cls._find_or_create_list(cls.test_passed_list)
            cls.failed_list = cls._find_or_create_list(cls.test_failed_list)
        else:
            cls.passed_list = cls._find_list(cls.test_passed_list)
            cls.failed_list = cls._find_list(cls.test_failed_list)

    @classmethod
    def _find_board(cls, name):
        for board in cls.trello_client.list_boards():
            if board.name == name:
                return board
        raise Exception(f'Board {name} not found.')

    @classmethod
    def _find_or_create_board(cls, name):
        try:
            board = cls._find_board(name)
        except Exception:
            board = cls.trello_client.add_board(name)
        return board

    @classmethod
    def _find_list(cls, name):
        for lst in cls.board.list_lists():
            if lst.name == name:
                return lst
        raise Exception(f'List {name} not found.')

    @classmethod
    def _find_or_create_list(cls, name):
        try:
            lst = cls._find_list(name)
        except Exception:
            lst = cls.board.add_list(name)
        return lst

    @classmethod
    def add_card(cls, lst, card_name, card_desc=''):
        return lst.add_card(name=card_name, desc=card_desc)

    @classmethod
    def move_card(cls, card, lst):
        card.change_list(lst.id)



import os
import unittest
from tresto import TrestoTestCase
from trello.exceptions import ResourceUnavailable


class TestTresto(TrestoTestCase):

    def setUp(self):
        self.card_failed = None
        self.card_passed = None

    def test_1_board_setup(self):
        self.assertIsNotNone(self.board)
        self.assertEqual(self.board.name, self.board_name)

    def test_2_list_setup(self):
        self.assertIsNotNone(self.passed_list)
        self.assertIsNotNone(self.failed_list)
        self.assertEqual(self.passed_list.name, self.test_passed_list)
        self.assertEqual(self.failed_list.name, self.test_failed_list)

    def test_3_add_and_delete_cards(self):
        # Test add_card and delete_card for FAILED List
        card_name_failed = "Test Card for FAILED List"
        self.card_failed = self.add_card(self.failed_list, card_name_failed)
        self.assertEqual(self.card_failed.name, card_name_failed)
        self.card_failed.delete()
        try:
            deleted_card_failed = self.board.get_card(self.card_failed.id)
            self.fail("Card was not deleted")
        except ResourceUnavailable:
            pass

        # Test add_card and delete_card for PASSED List
        card_name_passed = "Test Card for PASSED List"
        self.card_passed = self.add_card(self.passed_list, card_name_passed)
        self.assertEqual(self.card_passed.name, card_name_passed)
        self.card_passed.delete()
        try:
            deleted_card_passed = self.board.get_card(self.card_passed.id)
            self.fail("Card was not deleted")
        except ResourceUnavailable:
            pass

    def test_4_add_and_move_card_between_lists(self):
        card_name = "Test Card for Moving Between Lists"
        card = self.add_card(self.passed_list, card_name)
        self.move_card(card, self.failed_list)

        # Refresh card data
        card.fetch()

        self.assertEqual(card.list_id, self.failed_list.id)
        card.delete()

if __name__ == '__main__':
    unittest.main()



import os
import unittest
from tresto import TrestoTestCase

def hello_world():
    return "Hello World"

class TestHelloWorld(TrestoTestCase):
    auto_create_board = True
    auto_create_lists = True

    def test_hello_world(self):
        result = hello_world()
        self.assertEqual(result, "Hello World")

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="tresto",
    version="0.1.1",
    author="Arturo 'Buanzo' Busleiman",
    author_email="buanzo@buanzo.com.ar",
    description="Python unit testing integrated with Trello, providing visualization of project status, ideal for test-driven development",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/buanzo/tresto",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'py-trello'
    ]
)
